;;; org-lisp-link.el --- Link for executing lisp on click
(defconst org-lisp-link-version "0.1")
;; Copyright (c)2008 Jonathan Arkell. (by)(nc)(sa)  Some rights reserved.
;; Author: Jonathan Arkell <jonnay@jonnay.net>

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation version 2.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; For a copy of the GNU General Public License, search the Internet,
;; or write to the Free Software Foundation, Inc., 59 Temple Place,
;; Suite 330, Boston, MA 02111-1307 USA

;;; Commentary:
;; This is decendent from Sacha Chua's lisp link plugin for planner

;;; Original Commentary:
;; Example:
;; [[lisp:/plan][Plan]] will be rendered as "Plan". Selecting the link
;; will run the plan function interactively.
;;
;; If the link is a lisp form it is evaluated non-interactively:
;; [[lisp:/(man "bash")][bash manual]] will be rendered as "bash
;; manual".  Selecting the link will show the bash man page in Emacs.

;;; Contributors:

;; Gerd Flaig fixed the docstring for `planner-lisp-browse-url'.

;; Jim Ottaway made it such that if the URL like a lisp form, read and
;; evaluate it, otherwise call it interactively as before.


;;; Installation:
;; Put org-lisp-link.el somewhere in your load-path.
;; (Use M-x show-variable RET load-path to see what your load path is.)
;; Add this to your emacs init file.
;(require 'org-lisp-link)


;;; Commands:
;;
;; Below are complete command list:
;;
;;
;;; Customizable Options:
;;
;; Below are customizable option list:
;;

;;; CHANGELOG:
;; v 0.1 - Initial release

;;; Code:

(defun org-lisp-browse-url (url)
  "If this is a LISP URL, evaluate it."
  (if (string-match "\\`\\s-*\\((.+)\\)\\s-*\\'" url)
	  (eval (read (match-string 1 url)))
	  (eval (read (concat "(call-interactively '" url ")")))))

(org-add-link-type "lisp" 'org-lisp-browse-url)

(provide 'org-lisp-link)

;;; org-lisp-link ends here